package cn.com.infosec.asn1.x509.qualified;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;
import java.util.Enumeration;

public class QCStatement extends ASN1Encodable implements ETSIQCObjectIdentifiers, RFC3739QCObjectIdentifiers {
   DERObjectIdentifier qcStatementId;
   ASN1Encodable qcStatementInfo;

   public static QCStatement getInstance(Object obj) {
      if (obj != null && !(obj instanceof QCStatement)) {
         if (obj instanceof ASN1Sequence) {
            return new QCStatement(ASN1Sequence.getInstance(obj));
         } else {
            throw new IllegalArgumentException("unknown object in getInstance");
         }
      } else {
         return (QCStatement)obj;
      }
   }

   public QCStatement(ASN1Sequence seq) {
      Enumeration seq1;
      this.qcStatementId = DERObjectIdentifier.getInstance((seq1 = seq.getObjects()).nextElement());
      if (seq1.hasMoreElements()) {
         this.qcStatementInfo = (ASN1Encodable)seq1.nextElement();
      }

   }

   public QCStatement(DERObjectIdentifier qcStatementId) {
      this.qcStatementId = qcStatementId;
      this.qcStatementInfo = null;
   }

   public QCStatement(DERObjectIdentifier qcStatementId, ASN1Encodable qcStatementInfo) {
      this.qcStatementId = qcStatementId;
      this.qcStatementInfo = qcStatementInfo;
   }

   public DERObjectIdentifier getStatementId() {
      return this.qcStatementId;
   }

   public ASN1Encodable getStatementInfo() {
      return this.qcStatementInfo;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var10001.add(this.qcStatementId);
      ASN1Encodable var2;
      if ((var2 = this.qcStatementInfo) != null) {
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
